@@ -14,6 +14,7 @@
 #    under the License.
 import collections
 import logging
+
 import pkg_resources
 import requests
 
@@ -64,7 +65,7 @@ class LazyRegistries(collections.MutableMapping):
     the BMC unless the consumer is actually trying to use them.
 
     :param service_root: Redfish service root object
-    :type service_root: Sushy
+    :type service_root: sushy.main.Sushy
     """
 
     def __init__(self, service_root):
@@ -364,16 +365,6 @@ class Sushy(base.ResourceBase):
             self._conn, self._session_service_path,
             redfish_version=self.redfish_version)
 
-    def get_sessions_path(self):
-        """Returns the Sessions url"""
-
-        try:
-            links_url = self.json.get('Links')
-            return links_url['Sessions']['@odata.id']
-        except (TypeError, KeyError):
-            raise exceptions.MissingAttributeError(
-                attribute='Links/Sessions/@data.id', resource=self.path)
-
     def get_session(self, identity):
         """Given the identity return a Session object
 
