@@ -15,8 +15,8 @@
 
 from http import client as http_client
 import json
+from unittest import mock
 
-import mock
 import requests
 
 from sushy import auth as sushy_auth
@@ -220,7 +220,6 @@ class ConnectorOpTestCase(base.TestCase):
         self.conn._session.headers['X-Auth-Token'] = 'asdf1234'
         expected_headers = self.headers.copy()
         expected_headers['OData-Version'] = '4.0'
-        expected_headers['Content-Type'] = 'application/json'
         self.conn._op('POST', path='fake/path', headers=self.headers,
                       data=self.data)
         self.request.assert_called_once_with(
@@ -286,7 +285,6 @@ class ConnectorOpTestCase(base.TestCase):
         response = self.conn._op('POST', path='fake/path', data=self.data,
                                  headers=self.headers)
         self.auth.refresh_session.assert_called_with()
-        self.auth.can_refresh_session.assert_called_with()
         self.assertEqual(response.json, second_response.json)
 
     def test_connection_error(self):
@@ -318,23 +316,7 @@ class ConnectorOpTestCase(base.TestCase):
         self.assertIsNotNone(exc.body)
         self.assertIn('body submitted was malformed JSON', exc.detail)
 
-    def test_known_http_error_nonlist_ext_info(self):
-        self.request.return_value.status_code =\
-            http_client.UNSUPPORTED_MEDIA_TYPE
-        with open('sushy/tests/unit/json_samples/'
-                  'error_single_ext_info.json') as f:
-            self.request.return_value.json.return_value = json.load(f)
-
-        with self.assertRaisesRegex(exceptions.HTTPError,
-                                    'See Resolution for information') as cm:
-            self.conn._op('POST', 'http://foo.bar')
-        exc = cm.exception
-        self.assertEqual(http_client.UNSUPPORTED_MEDIA_TYPE, exc.status_code)
-        self.assertIsNotNone(exc.body)
-        self.assertIn('See Resolution for information', exc.detail)
-
-    @mock.patch('time.sleep', autospec=True)
-    def test_not_found_error(self, mock_sleep):
+    def test_not_found_error(self):
         self.request.return_value.status_code = http_client.NOT_FOUND
         self.request.return_value.json.side_effect = ValueError('no json')
 
@@ -343,11 +325,8 @@ class ConnectorOpTestCase(base.TestCase):
             self.conn._op('GET', 'http://foo.bar')
         exc = cm.exception
         self.assertEqual(http_client.NOT_FOUND, exc.status_code)
-        self.assertFalse(mock_sleep.called)
-        self.assertEqual(1, self.request.call_count)
 
-    @mock.patch('time.sleep', autospec=True)
-    def test_server_error(self, mock_sleep):
+    def test_server_error(self):
         self.request.return_value.status_code = (
             http_client.INTERNAL_SERVER_ERROR)
         self.request.return_value.json.side_effect = ValueError('no json')
@@ -357,8 +336,6 @@ class ConnectorOpTestCase(base.TestCase):
             self.conn._op('GET', 'http://foo.bar')
         exc = cm.exception
         self.assertEqual(http_client.INTERNAL_SERVER_ERROR, exc.status_code)
-        self.assertEqual(5, mock_sleep.call_count)
-        self.assertEqual(6, self.request.call_count)
 
     def test_access_error(self):
         self.conn._auth.can_refresh_session.return_value = False
@@ -372,24 +349,6 @@ class ConnectorOpTestCase(base.TestCase):
         exc = cm.exception
         self.assertEqual(http_client.FORBIDDEN, exc.status_code)
 
-    @mock.patch.object(connector.LOG, 'debug', autospec=True)
-    def test_access_error_service_session(self, mock_log):
-        self.conn._auth.can_refresh_session.return_value = False
-
-        self.request.return_value.status_code = http_client.FORBIDDEN
-        self.request.return_value.json.side_effect = ValueError('no json')
-
-        with self.assertRaisesRegex(exceptions.AccessError,
-                                    'unknown error') as cm:
-            self.conn._op('GET', 'http://redfish/v1/SessionService')
-        exc = cm.exception
-        mock_log.assert_called_with(
-            'HTTP GET of SessionService failed %s, '
-            'this is expected prior to authentication', 'HTTP GET '
-            'http://redfish/v1/SessionService returned code '
-            'HTTPStatus.FORBIDDEN. unknown error')
-        self.assertEqual(http_client.FORBIDDEN, exc.status_code)
-
     def test_blocking_no_location_header(self):
         self.request.return_value.status_code = http_client.ACCEPTED
         self.request.return_value.headers = {'retry-after': 5}
