@@ -15,7 +15,6 @@
 
 import collections
 import functools
-
 import logging
 import threading
 
@@ -329,15 +328,3 @@ def synchronized(wrapped):
             return wrapped(*args, **kwargs)
 
     return wrapper
-
-
-_REMOVE = frozenset(['password', 'x-auth-token'])
-
-
-def sanitize(item):
-    """Remove passwords from the item."""
-    if isinstance(item, dict):
-        return {key: ('***' if key.lower() in _REMOVE else sanitize(value))
-                for key, value in item.items()}
-    else:
-        return item
